# 🌀 blue-south

AI with no Big Tech dependency for the Global South.

```bash
pip install blue-south
```

|   |   |   |
| --- | --- | --- |
| [`feature 1`](#) [![image](https://github.com/kamangir/assets/raw/main/blue-south/marquee.png?raw=true)](#) description of feature 1 ... | [`feature 2`](#) [![image](https://github.com/kamangir/assets/raw/main/blue-south/marquee.png?raw=true)](#) description of feature 2 ... | [`feature 3`](#) [![image](https://github.com/kamangir/assets/raw/main/blue-south/marquee.png?raw=true)](#) description of feature 3 ... |

---


[![pylint](https://github.com/kamangir/blue-south/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blue-south/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blue-south/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blue-south/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/blue-south/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/blue-south/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blue-south.svg)](https://pypi.org/project/blue-south/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blue-south)](https://pypistats.org/packages/blue-south)

built by 🌀 [`blue_options-4.240.1`](https://github.com/kamangir/awesome-bash-cli), based on 🌀 [`blue_south-4.3.1`](https://github.com/kamangir/blue-south).
